==> tomee-project-8.0.16-source-release.zip: tomee-project-8.0.16/container/openejb-jee/src/main/java/org/apache/openejb/jee/sun/ServiceQname.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.jee.sun;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {"namespaceURI", "localpart"})
public class ServiceQname {
    @XmlElement(required = true)
    protected String namespaceURI;
    @XmlElement(required = true)
    protected String localpart;

    public String getNamespaceURI() {
        return namespaceURI;
    }

    public void setNamespaceURI(final String value) {
        this.namespaceURI = value;
    }

    public String getLocalpart() {
        return localpart;
    }

    public void setLocalpart(final String value) {
        this.localpart = value;
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-jee/src/main/java/org/apache/openejb/jee/sun/ServiceQname.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.jee.sun;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {"namespaceURI", "localpart"})
public class ServiceQname {
    @XmlElement(required = true)
    protected String namespaceURI;
    @XmlElement(required = true)
    protected String localpart;

    public String getNamespaceURI() {
        return namespaceURI;
    }

    public void setNamespaceURI(final String value) {
        this.namespaceURI = value;
    }

    public String getLocalpart() {
        return localpart;
    }

    public void setLocalpart(final String value) {
        this.localpart = value;
    }
}
